Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <campbell@blender.org>2022-05-05 03:41:00 +0300
committerCampbell Barton <campbell@blender.org>2022-05-05 03:44:25 +0300
commitd0c2fd05701056d545cce0e6b44260c4fe071bcb (patch)
treee11cdb47af2eb0c0d6faec740e31802d1eb76eb9 /source/blender/imbuf/intern/IMB_filetype.h
parentd3c895fc41d7a2d4ec677c4cd70f656a28f8edb1 (diff)
Cleanup: use 'r_' prefix for return arguments
Diffstat (limited to 'source/blender/imbuf/intern/IMB_filetype.h')
-rw-r--r--source/blender/imbuf/intern/IMB_filetype.h18
1 files changed, 10 insertions, 8 deletions
diff --git a/source/blender/imbuf/intern/IMB_filetype.h b/source/blender/imbuf/intern/IMB_filetype.h
index bcca6f9fd85..67d1aefeacb 100644
--- a/source/blender/imbuf/intern/IMB_filetype.h
+++ b/source/blender/imbuf/intern/IMB_filetype.h
@@ -36,15 +36,17 @@ typedef struct ImFileType {
char colorspace[IM_MAX_SPACE]);
/** Load an image from a file. */
struct ImBuf *(*load_filepath)(const char *filepath, int flags, char colorspace[IM_MAX_SPACE]);
- /** Load/Create a thumbnail image from a filepath. `max_thumb_size` is maximum size of either
+ /**
+ * Load/Create a thumbnail image from a filepath. `max_thumb_size` is maximum size of either
* dimension, so can return less on either or both. Should, if possible and performant, return
* dimensions of the full-size image in width_r & height_r. */
struct ImBuf *(*load_filepath_thumbnail)(const char *filepath,
const int flags,
const size_t max_thumb_size,
- size_t *width_r,
- size_t *height_r,
- char colorspace[IM_MAX_SPACE]);
+ char colorspace[IM_MAX_SPACE],
+ size_t *r_width,
+ size_t *r_height);
/** Save to a file (or memory if #IB_mem is set in `flags` and the format supports it). */
bool (*save)(struct ImBuf *ibuf, const char *filepath, int flags);
void (*load_tile)(struct ImBuf *ibuf,
@@ -155,9 +157,9 @@ struct ImBuf *imb_load_jpeg(const unsigned char *buffer,
struct ImBuf *imb_thumbnail_jpeg(const char *filepath,
const int flags,
const size_t max_thumb_size,
- size_t *width_r,
- size_t *height_r,
- char colorspace[IM_MAX_SPACE]);
+ char colorspace[IM_MAX_SPACE],
+ size_t *r_width,
+ size_t *r_height);
/** \} */
@@ -36,15 +36,17 @@ typedef struct ImFileType {
* dimension, so can return less on either or both. Should, if possible and performant, return
- * dimensions of the full-size image in width_r & height_r. */
+ * dimensions of the full-size image in r_width & r_height.
+ */
struct ImBuf *(*load_filepath_thumbnail)(const char *filepath,
const int flags,